aboutsummaryrefslogtreecommitdiff
path: root/gcc/reload1.c
diff options
context:
space:
mode:
authorJan Hubicka <jh@suse.cz>2000-02-09 14:38:09 +0100
committerJan Hubicka <hubicka@gcc.gnu.org>2000-02-09 13:38:09 +0000
commit665792ebecf527818aa1fcaf31b90307204cef30 (patch)
tree47b93c3d10d0764594f803b9725a0009b6023c2d /gcc/reload1.c
parent1f7d1a5255c89ae48a1fae6931eea74282901bfd (diff)
downloadgcc-665792ebecf527818aa1fcaf31b90307204cef30.zip
gcc-665792ebecf527818aa1fcaf31b90307204cef30.tar.gz
gcc-665792ebecf527818aa1fcaf31b90307204cef30.tar.bz2
* reload1.c (reload) Align stack frame to cfun->stack_alignment_needed,
not to BIGGEST_ALIGNMENT. From-SVN: r31860
Diffstat (limited to 'gcc/reload1.c')
-rw-r--r--gcc/reload1.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/gcc/reload1.c b/gcc/reload1.c
index 4745773..f0aec44 100644
--- a/gcc/reload1.c
+++ b/gcc/reload1.c
@@ -841,11 +841,12 @@ reload (first, global, dumpfile)
HOST_WIDE_INT starting_frame_size;
/* Round size of stack frame to BIGGEST_ALIGNMENT. This must be done
here because the stack size may be a part of the offset computation
for register elimination, and there might have been new stack slots
created in the last iteration of this loop. */
- assign_stack_local (BLKmode, 0, 0);
+ if (cfun->stack_alignment_needed)
+ assign_stack_local (BLKmode, 0, cfun->stack_alignment_needed);
starting_frame_size = get_frame_size ();
@@ -841,11 +841,12 @@ reload (first, global, dumpfile)
HOST_WIDE_INT starting_frame_size;
- /* Round size of stack frame to BIGGEST_ALIGNMENT. This must be done
+ /* Round size of stack frame to stack_alignment_needed. This must be done
here because the stack size may be a part of the offset computation
for register elimination, and there might have been new stack slots